@@ -18,9 +18,12 @@ end
 class B
 end
 class Object
-  def test: -> untyped
+  def test: -> :foo_a
 end
 
+## diagnostics: test.rb
+(6,6)-(6,9): wrong type of arguments
+
 ## update: test.rb
 class A
 end
@@ -38,3 +41,5 @@ end
 class Object
   def test: -> :foo_a
 end
+
+## diagnostics: test.rb
