@@ -7,7 +7,7 @@ end
 foo
 
 ## hover: test.rb:6:0
-Object#foo : -> ::Integer
+Object#foo : -> Integer
 
 ## diagnostics
 (3,2)-(3,10): expected: Integer; actual: String
@@ -21,7 +21,7 @@ end
 foo
 
 ## hover: test.rb:6:0
-Object#foo : -> ::Integer?
+Object#foo : -> Integer?
 
 ## update: test.rb
 #: () -> (Integer | String)?
@@ -34,4 +34,4 @@ foo
 # TODO: The above test is mainly for SIG_TYPE#show
 
 ## hover: test.rb:6:0
-Object#foo : -> (::Integer | ::String)?
+Object#foo : -> (Integer | String)?
